-----------------------------------------------------------------------------

local roster = AceLibrary("Roster-2.1")
local AloftUnitidData = Aloft:NewModule("UnitidData", "AceEvent-2.0")

-----------------------------------------------------------------------------

local function IsGrouped()
	return GetNumPartyMembers() > 0 or GetNumRaidMembers() > 0
end

local lastGrouped = false

function AloftUnitidData:ProvidesData()
	if IsGrouped() then
		return "unitid"
	else
		return nil
	end
end

-----------------------------------------------------------------------------

function AloftUnitidData:OnEnable()
	self:RegisterEvent("RosterLib_RosterUpdated", "RosterUpdated")
	lastGrouped = IsGrouped()
end

function AloftUnitidData:OnDisable()
	self:UnregisterAllEvents()
end

-- This data source overrides DisableDataSource because we still want RosterUpdated events to be caught even if this data source isn't used at the moment
function AloftUnitidData:DisableDataSource()
	self:RemoveAloftData("unitid")
end

function AloftUnitidData:RosterUpdated()
	local grouped = IsGrouped()
	if grouped ~= lastGrouped then
		lastGrouped = grouped
		Aloft:DetermineDataSources()
	end
end

-----------------------------------------------------------------------------

function AloftUnitidData:UpdateData(aloftData)
	aloftData.unitid = roster:GetUnitIDFromName(aloftData.name)
end

-----------------------------------------------------------------------------
